==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_emoticon.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_emoticon.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("EMOLAN_1", "Emote activation");
define("EMOLAN_2", "Name");
define("EMOLAN_3", "Emotes");
define("EMOLAN_4", "Activate emoticons?");

define("EMOLAN_5", "Image");
define("EMOLAN_6", "Emote Code");
define("EMOLAN_7", "separate multiple entries with spaces");

define("EMOLAN_8", "Status");
define("EMOLAN_9", "Options");
define("EMOLAN_10", "Active");
define("EMOLAN_11", "Activate pack");

define("EMOLAN_12", "Edit / configure this pack");
define("EMOLAN_13", "Installed packs");

define("EMOLAN_14", "Save configuration");
define("EMOLAN_15", "Edit / configure emotes");
define("EMOLAN_16", "Emote configuration saved");
define("EMOLAN_17", "You have an emoticon pack present that contains spaces in the name, which are not allowed !");
define("EMOLAN_18", "please rename the instances listed below so they no longer contain spaces:");
define("EMOLAN_19", "Name");
define("EMOLAN_20", "Location");
define("EMOLAN_21", "Error");
//define("EMOLAN_2", "Name");
define("EMOLAN_22", "New emote pak found:");
define("EMOLAN_23", "New emote xml pak found:");
define("EMOLAN_24", "New emote php found:");
define("EMOLAN_25", "Installing new PHP emotes: ");
define("EMOLAN_26", "Re-scan pack");
define("EMOLAN_27", "Error occurred processing pack: ");
define("EMOLAN_28", "Generate XML");
define("EMOLAN_29", "XML file generated: ");
define("EMOLAN_30", "Error writing XML file: ");
?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_emoticon.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_emoticon.php $
|     $Revision: 11678 $
|     $Id: lan_emoticon.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("EMOLAN_1", "Emote activation");
define("EMOLAN_2", "Name");
define("EMOLAN_3", "Emotes");
define("EMOLAN_4", "Activate emoticons?");

define("EMOLAN_5", "Image");
define("EMOLAN_6", "Emote Code");
define("EMOLAN_7", "separate multiple entries with spaces");

define("EMOLAN_8", "Status");
define("EMOLAN_9", "Options");
define("EMOLAN_10", "Active");
define("EMOLAN_11", "Activate pack");

define("EMOLAN_12", "Edit / configure this pack");
define("EMOLAN_13", "Installed packs");

define("EMOLAN_14", "Save configuration");
define("EMOLAN_15", "Edit / configure emotes");
define("EMOLAN_16", "Emote configuration saved");
define("EMOLAN_17", "You have an emoticon pack present that contains spaces in the name, which are not allowed !");
define("EMOLAN_18", "please rename the instances listed below so they no longer contain spaces:");
define("EMOLAN_19", "Name");
define("EMOLAN_20", "Location");
define("EMOLAN_21", "Error");
//define("EMOLAN_2", "Name");
define("EMOLAN_22", "New emote pak found:");
define("EMOLAN_23", "New emote xml pak found:");
define("EMOLAN_24", "New emote php found:");
define("EMOLAN_25", "Installing new PHP emotes: ");
define("EMOLAN_26", "Re-scan pack");
define("EMOLAN_27", "Error occurred processing pack: ");
define("EMOLAN_28", "Generate XML");
define("EMOLAN_29", "XML file generated: ");
define("EMOLAN_30", "Error writing XML file: ");
?>
